function USB225_ReadData
    % Create the GUI figure
    hFig = figure('Position', [100, 100, 400, 300], 'MenuBar', 'none', ...
                  'Name', 'FUTEK.Devices USB225 Example', 'NumberTitle', 'off', ...
                  'CloseRequestFcn', @closeGUI);

    % Add UI components
    hConnectButton = uicontrol('Style', 'pushbutton', 'String', 'Connect', ...
                             'Position', [50, 200, 100, 40], ...
                             'Callback', @connectDevice);

    hDisconnectButton = uicontrol('Style', 'pushbutton', 'String', 'Disconnect', ...
                            'Position', [250, 200, 100, 40], ...
                            'Callback', @disconnectDevice, 'Enable', 'off');

    hReadButton = uicontrol('Style', 'pushbutton', 'String', 'Read Data', ...
                            'Position', [150, 200, 100, 40], ...
                            'Callback', @readData, 'Enable', 'off');

    hSerialNumberText = uicontrol('Style', 'text', 'String', 'Serial Number:', ...
                                  'Position', [50, 150, 300, 20], 'HorizontalAlignment', 'left');

    hModelNumberText = uicontrol('Style', 'text', 'String', 'Model Number:', ...
                                 'Position', [50, 120, 300, 20], 'HorizontalAlignment', 'left');

    hUnitOfMeasureText = uicontrol('Style', 'text', 'String', 'Unit of Measure:', ...
                                   'Position', [50, 90, 300, 20], 'HorizontalAlignment', 'left');

    hReadingText = uicontrol('Style', 'text', 'String', 'Reading:', ...
                             'Position', [50, 60, 300, 20], 'HorizontalAlignment', 'left');

    % Variables to manage device state
    device = [];

    % Load .NET assemblies and create device repository
    NET.addAssembly(which('FTD2XX_NET.dll'));
    NET.addAssembly(which('FUTEK.Devices.dll'));
    import FUTEK.Devices.*
    repo = DeviceRepository();

    % Callback function for Connect button
    function connectDevice(~, ~)
        try
            connectedDevices = repo.DetectDevices();
            if isempty(connectedDevices)
                errordlg('No devices detected. Please connect a device and try again.');
                return;
            end

            dc = NET.createGeneric('System.Collections.Generic.List', {'FUTEK.Devices.Device'}, 1);
            AddRange(dc, connectedDevices);
            device = dc.Item(0);

            serialNumber = device.GetInstrumentSerialNumber();
            modelNumber = device.GetModelNumber();
            unitOfMeasure = device.GetChannelXUnitOfMeasure(0);

            set(hSerialNumberText, 'String', ['Serial Number: ' char(serialNumber)]);
            set(hModelNumberText, 'String', ['Model Number: ' char(modelNumber)]);
            set(hUnitOfMeasureText, 'String', ['Unit of Measure: ' char(unitOfMeasure)]);

            set(hConnectButton, 'Enable', 'off');
            set(hDisconnectButton, 'Enable', 'on');
            set(hReadButton, 'Enable', 'on');
        catch ex
            errordlg(['Error connecting to device: ' ex.message]);
        end
    end

    % Callback function for Disconnect button
    function disconnectDevice(~, ~)
        try
            repo.DisconnectAllDevices();
            set(hConnectButton, 'Enable', 'on');
            set(hDisconnectButton, 'Enable', 'off');
            set(hReadButton, 'Enable', 'off');
            device = [];
            set(hSerialNumberText, 'String', 'Serial Number:');
            set(hModelNumberText, 'String', 'Model Number:');
            set(hUnitOfMeasureText, 'String', 'Unit of Measure:');
            set(hReadingText, 'String', 'Reading:');
        catch ex
            errordlg(['Error disconnecting device: ' ex.message]);
        end
    end

    % Callback function to read data
    function readData(~, ~)
        try
            if isempty(device)
                errordlg('No device connected. Please connect a device first.');
                return;
            end
            reading = device.GetChannelXReading(0);
            set(hReadingText, 'String', ['Reading: ' num2str(reading)]);
        catch ex
            errordlg(['Error reading data: ' ex.message]);
        end
    end

    % Callback function for closing the GUI
    function closeGUI(~, ~)
        disconnectDevice();
        delete(hFig);
    end
end