function USB225_ReadDataStream
    % Create the GUI figure
    hFig = figure('Position', [100, 100, 400, 300], 'MenuBar', 'none', ...
                  'Name', 'FUTEK.Devices USB225 Streaming Example', 'NumberTitle', 'off', ...
                  'CloseRequestFcn', @closeGUI);

    % Add UI components
    hStartButton = uicontrol('Style', 'pushbutton', 'String', 'Start', ...
                             'Position', [50, 200, 100, 40], ...
                             'Callback', @startReading);

    hStopButton = uicontrol('Style', 'pushbutton', 'String', 'Stop', ...
                            'Position', [250, 200, 100, 40], ...
                            'Callback', @stopReading, 'Enable', 'off');

    hSerialNumberText = uicontrol('Style', 'text', 'String', 'Serial Number:', ...
                                  'Position', [50, 150, 300, 20], 'HorizontalAlignment', 'left');

    hModelNumberText = uicontrol('Style', 'text', 'String', 'Model Number:', ...
                                 'Position', [50, 120, 300, 20], 'HorizontalAlignment', 'left');

    hUnitOfMeasureText = uicontrol('Style', 'text', 'String', 'Unit of Measure:', ...
                                   'Position', [50, 90, 300, 20], 'HorizontalAlignment', 'left');

    hReadingText = uicontrol('Style', 'text', 'String', 'Reading:', ...
                             'Position', [50, 60, 300, 20], 'HorizontalAlignment', 'left');

    % Variables to manage device and streaming state
    device = [];
    readingTimer = [];
    streamingInterval = 0.1; % interval in seconds between readings

    % Load .NET assemblies and create device repository
    NET.addAssembly(which('FTD2XX_NET.dll'));
    NET.addAssembly(which('FUTEK.Devices.dll'));
    import FUTEK.Devices.*
    repo = DeviceRepository();

    % Callback function for Start button
    function startReading(~, ~)
        try
            connectedDevices = repo.DetectDevices();
            if isempty(connectedDevices)
                errordlg('No devices detected. Please connect a device and try again.');
                return;
            end

            dc = NET.createGeneric('System.Collections.Generic.List', {'FUTEK.Devices.Device'}, 1);
            AddRange(dc, connectedDevices);
            device = dc.Item(0);

            serialNumber = device.GetInstrumentSerialNumber();
            modelNumber = device.GetModelNumber();
            unitOfMeasure = device.GetChannelXUnitOfMeasure(0);

            set(hSerialNumberText, 'String', ['Serial Number: ' char(serialNumber)]);
            set(hModelNumberText, 'String', ['Model Number: ' char(modelNumber)]);
            set(hUnitOfMeasureText, 'String', ['Unit of Measure: ' char(unitOfMeasure)]);

            set(hStartButton, 'Enable', 'off');
            set(hStopButton, 'Enable', 'on');

            % Set up a timer for reading data at intervals
            readingTimer = timer('ExecutionMode', 'fixedSpacing', ...
                                 'Period', streamingInterval, ...
                                 'TimerFcn', @readData);
            start(readingTimer);
        catch ex
            errordlg(['Error starting reading: ' ex.message]);
        end
    end

    % Callback function for Stop button
    function stopReading(~, ~)
        if ~isempty(readingTimer)
            stop(readingTimer);
            delete(readingTimer);
            readingTimer = [];
        end
        set(hStartButton, 'Enable', 'on');
        set(hStopButton, 'Enable', 'off');
        repo.DisconnectAllDevices();
    end

    % Timer callback function to read data
    function readData(~, ~)
        try
            reading = device.GetChannelXReading(0);
            set(hReadingText, 'String', ['Reading: ' num2str(reading)]);
        catch ex
            stopReading();
            errordlg(['Error reading data: ' ex.message]);
        end
    end

    % Callback function for closing the GUI
    function closeGUI(~, ~)
        stopReading();
        delete(hFig);
    end
end
